Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(255)

Unified Diff: src/gpu/batches/GrDrawBatch.h

Issue 1888473002: Use transfer buffer for BatchAtlas texture copies Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: Rebase to ToT Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/gpu/GrResourceProvider.cpp ('k') | src/gpu/gl/GrGLAssembleInterface.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/gpu/batches/GrDrawBatch.h
diff --git a/src/gpu/batches/GrDrawBatch.h b/src/gpu/batches/GrDrawBatch.h
index 5f37b7b0001fbc39026b3c0a9fa595340748ab7b..d1622a1cd13b2ba5aa31b421caa4982cc7d1654e 100644
--- a/src/gpu/batches/GrDrawBatch.h
+++ b/src/gpu/batches/GrDrawBatch.h
@@ -46,13 +46,18 @@ private:
*/
class GrDrawBatch : public GrBatch {
public:
/** Method that performs an upload on behalf of a DeferredUploadFn. */
using WritePixelsFn = std::function<bool(GrSurface* texture,
int left, int top, int width, int height,
- GrPixelConfig config, const void* buffer,
+ GrPixelConfig config, const void* buffer,
size_t rowBytes)>;
+ using TransferPixelsFn = std::function<bool(GrTexture* texture,
+ int left, int top, int width, int height,
+ GrPixelConfig config, GrBuffer* buffer,
+ size_t offset, size_t rowBytes,
+ GrFence* fence)>;
/** See comments before GrDrawBatch::Target definition on how deferred uploaders work. */
- using DeferredUploadFn = std::function<void(WritePixelsFn&)>;
+ using DeferredUploadFn = std::function<void(WritePixelsFn&, TransferPixelsFn&)>;
class Target;
« no previous file with comments | « src/gpu/GrResourceProvider.cpp ('k') | src/gpu/gl/GrGLAssembleInterface.cpp » ('j') | no next file with comments »
@@ -46,13 +46,18 @@ private:
class GrDrawBatch : public GrBatch {
public:
- /** Method that performs an upload on behalf of a DeferredUploadFn. */
+ /** Method that performs a texture write on behalf of a DeferredUploadFn. */
using WritePixelsFn = std::function<bool(GrSurface* texture,
int left, int top, int width, int height,

Powered by Google App Engine
This is Rietveld 408576698